#ifndef _GST_PLUGINS_BASE__STDINT_H
#define _GST_PLUGINS_BASE__STDINT_H 1
#ifndef _GENERATED_STDINT_H
#define _GENERATED_STDINT_H "gst-plugins-base 0.10.30.2"
/* generated using gnu compiler gcc (Debian 4.4.5-3) 4.4.5 */
#define _STDINT_HAVE_STDINT_H 1
#include <stdint.h>
#endif
#endif
